# adiumentum


With Nix installed, you can enter a development environment with all dependencies installed:

```sh
nix develop
```

Once in this dev shell, you have a number of development utils you can try out (via just):

```sh
✔just
✔just format
✔just check
✔just fix
✔just typecheck
✔just lint
✔just deal
✔just vulture
✔just pydeps-full
✔just pydeps
✔just pydeps-simple
✔just view-deps
✔just snakefood
✔just deply
✔just bandit
✔just bandit-html
✔just bandit-view
✔just pyflame
✔just flamegraph
✔just perf-flamegraph
✔just check-structure
✔just check-imports
✔just smoke
✔just unit
✔just test
✔just test-cov
✔just docs
✔just scalene
✔just view-cov
✔just view-docs
✔just view-flamegraphs
✔just sbom

lefthook validate
lefthook run all
```
